@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
     "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -62,6 +63,19 @@ types: list[str] = [
     "AWS::AppConfig::Extension",
     "AWS::AppConfig::ExtensionAssociation",
     "AWS::AppConfig::HostedConfigurationVersion",
+    "AWS::AppStream::AppBlock",
+    "AWS::AppStream::AppBlockBuilder",
+    "AWS::AppStream::Application",
+    "AWS::AppStream::ApplicationEntitlementAssociation",
+    "AWS::AppStream::ApplicationFleetAssociation",
+    "AWS::AppStream::DirectoryConfig",
+    "AWS::AppStream::Entitlement",
+    "AWS::AppStream::Fleet",
+    "AWS::AppStream::ImageBuilder",
+    "AWS::AppStream::Stack",
+    "AWS::AppStream::StackFleetAssociation",
+    "AWS::AppStream::StackUserAssociation",
+    "AWS::AppStream::User",
     "AWS::AppSync::Api",
     "AWS::AppSync::ApiCache",
     "AWS::AppSync::ApiKey",
@@ -98,8 +112,13 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::Guardrail",
+    "AWS::Bedrock::GuardrailVersion",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
+    "AWS::Chatbot::CustomAction",
+    "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
+    "AWS::Chatbot::SlackChannelConfiguration",
     "AWS::CloudFormation::CustomResource",
     "AWS::CloudFormation::GuardHook",
     "AWS::CloudFormation::HookDefaultVersion",
@@ -116,6 +135,7 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionFunction",
     "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
@@ -129,7 +149,11 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudFront::TrustStore",
     "AWS::CloudFront::VpcOrigin",
+    "AWS::CloudTrail::Dashboard",
+    "AWS::CloudTrail::EventDataStore",
+    "AWS::CloudTrail::ResourcePolicy",
     "AWS::CloudTrail::Trail",
     "AWS::CloudWatch::Alarm",
     "AWS::CloudWatch::AnomalyDetector",
@@ -161,7 +185,11 @@ types: list[str] = [
     "AWS::Config::ConfigRule",
     "AWS::Config::ConfigurationAggregator",
     "AWS::Config::ConfigurationRecorder",
+    "AWS::Config::ConformancePack",
     "AWS::Config::DeliveryChannel",
+    "AWS::Config::OrganizationConfigRule",
+    "AWS::Config::OrganizationConformancePack",
+    "AWS::Config::RemediationConfiguration",
     "AWS::Config::StoredQuery",
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
@@ -184,6 +212,21 @@ types: list[str] = [
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::Task",
+    "AWS::DataZone::DataSource",
+    "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
+    "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration",
+    "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
+    "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
+    "AWS::DataZone::Project",
+    "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::SubscriptionTarget",
+    "AWS::DataZone::UserProfile",
     "AWS::DirectoryService::MicrosoftAD",
     "AWS::DirectoryService::SimpleAD",
     "AWS::DynamoDB::GlobalTable",
@@ -253,6 +296,8 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
     "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -274,6 +319,7 @@ types: list[str] = [
     "AWS::EC2::VPCEndpointServicePermissions",
     "AWS::EC2::VPCGatewayAttachment",
     "AWS::EC2::VPCPeeringConnection",
+    "AWS::EC2::VPNConcentrator",
     "AWS::EC2::VPNConnection",
     "AWS::EC2::VPNConnectionRoute",
     "AWS::EC2::VPNGateway",
@@ -281,6 +327,7 @@ types: list[str] = [
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
@@ -289,6 +336,7 @@ types: list[str] = [
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
+    "AWS::ECS::ExpressGatewayService",
     "AWS::ECS::PrimaryTaskSet",
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
@@ -298,6 +346,7 @@ types: list[str] = [
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
+    "AWS::EKS::Capability",
     "AWS::EKS::Cluster",
     "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
@@ -332,6 +381,7 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
+    "AWS::Events::EventBusPolicy",
     "AWS::Events::Rule",
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
@@ -485,6 +535,7 @@ types: list[str] = [
     "AWS::MSK::Cluster",
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
+    "AWS::MSK::Replicator",
     "AWS::MSK::VpcConnection",
     "AWS::MWAA::Environment",
     "AWS::Neptune::DBCluster",
@@ -608,6 +659,22 @@ types: list[str] = [
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
+    "AWS::SES::ConfigurationSet",
+    "AWS::SES::ConfigurationSetEventDestination",
+    "AWS::SES::ContactList",
+    "AWS::SES::DedicatedIpPool",
+    "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
+    "AWS::SES::Template",
+    "AWS::SES::VdmAttributes",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
@@ -718,6 +785,7 @@ cached: list[str] = [
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -751,29 +819,43 @@ cached: list[str] = [
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
+    "aws-applicationautoscaling-scalabletarget.json",
+    "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
+    "aws-appstream-applicationentitlementassociation.json",
+    "aws-appstream-applicationfleetassociation.json",
+    "aws-appstream-directoryconfig.json",
+    "aws-appstream-entitlement.json",
+    "aws-appstream-fleet.json",
+    "aws-appstream-stack.json",
+    "aws-appstream-stackfleetassociation.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
     "aws-appsync-channelnamespace.json",
+    "aws-appsync-datasource.json",
     "aws-appsync-domainname.json",
     "aws-appsync-domainnameapiassociation.json",
     "aws-appsync-functionconfiguration.json",
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
-    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
@@ -789,7 +871,12 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-guardrail.json",
+    "aws-bedrock-guardrailversion.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
+    "aws-chatbot-microsoftteamschannelconfiguration.json",
+    "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
     "aws-cloudformation-guardhook.json",
     "aws-cloudformation-hookdefaultversion.json",
@@ -804,6 +891,7 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectionfunction.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
@@ -817,7 +905,11 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudfront-truststore.json",
     "aws-cloudfront-vpcorigin.json",
+    "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
+    "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
@@ -845,7 +937,11 @@ cached: list[str] = [
     "aws-config-configrule.json",
     "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
+    "aws-config-conformancepack.json",
     "aws-config-deliverychannel.json",
+    "aws-config-organizationconfigrule.json",
+    "aws-config-organizationconformancepack.json",
+    "aws-config-remediationconfiguration.json",
     "aws-config-storedquery.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
@@ -863,6 +959,20 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
+    "aws-datazone-datasource.json",
+    "aws-datazone-domainunit.json",
+    "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
+    "aws-datazone-environmentblueprintconfiguration.json",
+    "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
+    "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
+    "aws-datazone-policygrant.json",
+    "aws-datazone-project.json",
+    "aws-datazone-projectmembership.json",
+    "aws-datazone-subscriptiontarget.json",
+    "aws-datazone-userprofile.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-dataprovider.json",
     "aws-dms-instanceprofile.json",
@@ -931,6 +1041,8 @@ cached: list[str] = [
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
     "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -954,11 +1066,13 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconcentrator.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
@@ -967,6 +1081,7 @@ cached: list[str] = [
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
+    "aws-ecs-expressgatewayservice.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -976,10 +1091,10 @@ cached: list[str] = [
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-capability.json",
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1006,6 +1121,7 @@ cached: list[str] = [
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-events-eventbus.json",
+    "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
@@ -1063,7 +1179,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1121,8 +1236,6 @@ cached: list[str] = [
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
-    "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1137,17 +1250,21 @@ cached: list[str] = [
     "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
+    "aws-msk-replicator.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
@@ -1162,15 +1279,21 @@ cached: list[str] = [
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
+    "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
     "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
     "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -1181,7 +1304,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
@@ -1228,6 +1350,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1285,6 +1408,22 @@ cached: list[str] = [
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-ses-configurationset.json",
+    "aws-ses-configurationseteventdestination.json",
+    "aws-ses-contactlist.json",
+    "aws-ses-dedicatedippool.json",
+    "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
+    "aws-ses-template.json",
+    "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
     "aws-shield-proactiveengagement.json",
     "aws-shield-protection.json",
